Page 76 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 76

Home

    And if a kingdom be divided against itself, that
    kingdom cannot stand.

    Aroa4

    Republic was a great victory for the American people,
    the struggle for freedom was not over; for, hardly had the
    ink dried on the Constitution before subversive forces,

    led by the Illuminati, set out to destroy the new Republic.
    It is an interesting coincidence that the first major
    uprising of the French Revolution, and the first meeting
    of the new United States Congress, both occurred in the
    spring of 1789. The same conspiracy that engineered the
    French Revolution, and the turmoil that kept France in

    chaos for over 80 years afterward, also jeopardized the
    new American Republic.

    Although, by the beginning of 1800, the Illuminati had
    set up, or taken control of, some lodges in America, they
    were never able to accomplish what they had done in
    France. The main reason for this was that, by 1800, most
    of the literate people in the United States knew about the
    Illuminati. This was partly due to the wide distribution of

    71

    Chapter 8

    Attempts to Divide America

    Mark 3:24

    Although the establishment of a Constitutional